cumulusci.core.tests package
============================

Submodules
----------

cumulusci.core.tests.BarTestPage module
---------------------------------------

.. automodule:: cumulusci.core.tests.BarTestPage
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.FooTestPage module
---------------------------------------

.. automodule:: cumulusci.core.tests.FooTestPage
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_config module
----------------------------------------

.. automodule:: cumulusci.core.tests.test_config
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_config\_expensive module
---------------------------------------------------

.. automodule:: cumulusci.core.tests.test_config_expensive
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_exceptions module
--------------------------------------------

.. automodule:: cumulusci.core.tests.test_exceptions
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_flowrunner module
--------------------------------------------

.. automodule:: cumulusci.core.tests.test_flowrunner
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_github module
----------------------------------------

.. automodule:: cumulusci.core.tests.test_github
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_keychain module
------------------------------------------

.. automodule:: cumulusci.core.tests.test_keychain
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_pageobjects module
---------------------------------------------

.. automodule:: cumulusci.core.tests.test_pageobjects
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_salesforce\_locators module
------------------------------------------------------

.. automodule:: cumulusci.core.tests.test_salesforce_locators
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_tasks module
---------------------------------------

.. automodule:: cumulusci.core.tests.test_tasks
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.test\_utils module
---------------------------------------

.. automodule:: cumulusci.core.tests.test_utils
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.tests.utils module
---------------------------------

.. automodule:: cumulusci.core.tests.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.core.tests
    :members:
    :undoc-members:
    :show-inheritance:
